<?php

namespace Chemical\Import\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Chemical\Import\Http\Requests\ImportRequest;
use Chemical\Import\Interfaces\ImportRepositoryInterface;
use Chemical\Import\Models\Import;

/**
 * Resource controller class for import.
 */
class ImportResourceController extends BaseController
{

    /**
     * Initialize import resource controller.
     *
     * @param type ImportRepositoryInterface $import
     *
     * @return null
     */
    public function __construct(ImportRepositoryInterface $import)
    {
        parent::__construct();
        $this->repository = $import;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Chemical\Import\Repositories\Criteria\ImportResourceCriteria::class);
    }

    /**
     * Display a list of import.
     *
     * @return Response
     */
    public function index(ImportRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Chemical\Import\Repositories\Presenter\ImportPresenter::class)
                ->$function();
        }

        $imports = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('import::import.names'))
            ->view('import::import.index', true)
            ->data(compact('imports', 'view'))
            ->output();
    }

    /**
     * Display import.
     *
     * @param Request $request
     * @param Model   $import
     *
     * @return Response
     */
    public function show(ImportRequest $request, Import $import)
    {

        if ($import->exists) {
            $view = 'import::import.show';
        } else {
            $view = 'import::import.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('import::import.name'))
            ->data(compact('import'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new import.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ImportRequest $request)
    {

        $import = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('import::import.name')) 
            ->view('import::import.create', true) 
            ->data(compact('import'))
            ->output();
    }

    /**
     * Create new import.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ImportRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $import                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('import::import.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('import/import/' . $import->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/import/import'))
                ->redirect();
        }

    }

    /**
     * Show import for editing.
     *
     * @param Request $request
     * @param Model   $import
     *
     * @return Response
     */
    public function edit(ImportRequest $request, Import $import)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('import::import.name'))
            ->view('import::import.edit', true)
            ->data(compact('import'))
            ->output();
    }

    /**
     * Update the import.
     *
     * @param Request $request
     * @param Model   $import
     *
     * @return Response
     */
    public function update(ImportRequest $request, Import $import)
    {
        try {
            $attributes = $request->all();

            $import->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('import::import.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('import/import/' . $import->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('import/import/' . $import->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the import.
     *
     * @param Model   $import
     *
     * @return Response
     */
    public function destroy(ImportRequest $request, Import $import)
    {
        try {

            $import->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('import::import.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('import/import/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('import/import/' . $import->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple import.
     *
     * @param Model   $import
     *
     * @return Response
     */
    public function delete(ImportRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('import::import.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('import/import'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/import/import'))
                ->redirect();
        }

    }

    /**
     * Restore deleted imports.
     *
     * @param Model   $import
     *
     * @return Response
     */
    public function restore(ImportRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('import::import.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/import/import'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/import/import/'))
                ->redirect();
        }

    }

}
